@@ -4,7 +4,11 @@ report.factor <- function(x, levels_percentage = "auto", ...) {
   if (!is.factor(x)) {
     x <- as.factor(x)
   }
-  report_table_obj <- report_table(x, levels_percentage = levels_percentage, ...)
+  report_table_obj <- report_table(
+    x,
+    levels_percentage = levels_percentage,
+    ...
+  )
   report_text_obj <- report_text(x, levels_percentage = levels_percentage, ...)
 
   as.report(report_text_obj, table = report_table_obj, ...)
@@ -19,7 +23,6 @@ report.Date <- report.factor
 
 # report_table ------------------------------------------------------------
 
-
 #' @export
 report_table.factor <- function(x, levels_percentage = "auto", ...) {
   if (!is.factor(x)) {
@@ -28,7 +31,10 @@ report_table.factor <- function(x, levels_percentage = "auto", ...) {
   levels_percentage <- .report_dataframe_percentage(x, levels_percentage)
 
   if (length(x[is.na(x)]) != 0) {
-    x <- factor(ifelse(is.na(x), "missing", as.character(x)), levels = c(levels(x), "missing"))
+    x <- factor(
+      ifelse(is.na(x), "missing", as.character(x)),
+      levels = c(levels(x), "missing")
+    )
   }
 
   # Table
@@ -39,7 +45,10 @@ report_table.factor <- function(x, levels_percentage = "auto", ...) {
   # Shorten
   report_table_obj <- table_full
   if (!levels_percentage) {
-    report_table_obj <- datawizard::data_remove(report_table_obj, "percentage_Obs")
+    report_table_obj <- datawizard::data_remove(
+      report_table_obj,
+      "percentage_Obs"
+    )
   }
 
   as.report_table(table_full, summary = report_table_obj)
@@ -54,9 +63,13 @@ report_table.Date <- report_table.factor
 
 # report_parameters -------------------------------------------------------
 
-
 #' @export
-report_parameters.factor <- function(x, table = NULL, levels_percentage = "auto", ...) {
+report_parameters.factor <- function(
+  x,
+  table = NULL,
+  levels_percentage = "auto",
+  ...
+) {
   if (!is.factor(x)) {
     x <- as.factor(x)
   }
@@ -67,23 +80,33 @@ report_parameters.factor <- function(x, table = NULL, levels_percentage = "auto"
 
   text_levels <- paste0(table$Level)
   text_n_Obs <- paste0("n = ", table$n_Obs)
-  text_percentage_Obs <- paste0(insight::format_value(table$percentage_Obs), "%")
+  text_percentage_Obs <- paste0(
+    insight::format_value(table$percentage_Obs),
+    "%"
+  )
 
   text_full <- paste0(
-    text_levels, " (",
-    text_n_Obs, ", ",
-    text_percentage_Obs, ")"
+    text_levels,
+    " (",
+    text_n_Obs,
+    ", ",
+    text_percentage_Obs,
+    ")"
   )
 
   if (isTRUE(levels_percentage)) {
     report_text_obj <- paste0(
-      text_levels, " (",
-      text_percentage_Obs, ")"
+      text_levels,
+      " (",
+      text_percentage_Obs,
+      ")"
     )
   } else {
     report_text_obj <- paste0(
-      text_levels, " (",
-      text_n_Obs, ")"
+      text_levels,
+      " (",
+      text_n_Obs,
+      ")"
     )
   }
 
@@ -100,7 +123,12 @@ report_parameters.Date <- report_parameters.factor
 # report_text -------------------------------------------------------------
 
 #' @export
-report_text.factor <- function(x, table = NULL, levels_percentage = "auto", ...) {
+report_text.factor <- function(
+  x,
+  table = NULL,
+  levels_percentage = "auto",
+  ...
+) {
   if (!is.factor(x)) {
     x <- as.factor(x)
   }
@@ -117,16 +145,37 @@ report_text.factor <- function(x, table = NULL, levels_percentage = "auto", ...)
   }
 
   table_no_missing <- table[table$Level != "missing", ]
-  params <- report_parameters(x, table = table, levels_percentage = levels_percentage, ...)
+  params <- report_parameters(
+    x,
+    table = table,
+    levels_percentage = levels_percentage,
+    ...
+  )
 
   if (nrow(table) > 1) {
-    text_total_levels <- paste0(name, ": ", nrow(table_no_missing), " levels, namely ")
+    text_total_levels <- paste0(
+      name,
+      ": ",
+      nrow(table_no_missing),
+      " levels, namely "
+    )
   } else {
-    text_total_levels <- paste0(name, ": ", nrow(table_no_missing), " level, namely ")
+    text_total_levels <- paste0(
+      name,
+      ": ",
+      nrow(table_no_missing),
+      " level, namely "
+    )
   }
 
-  text_full <- paste0(text_total_levels, datawizard::text_concatenate(params, sep = ", "))
-  report_text_obj <- paste0(text_total_levels, datawizard::text_concatenate(summary(params), sep = ", "))
+  text_full <- paste0(
+    text_total_levels,
+    datawizard::text_concatenate(params, sep = ", ")
+  )
+  report_text_obj <- paste0(
+    text_total_levels,
+    datawizard::text_concatenate(summary(params), sep = ", ")
+  )
 
   as.report_text(text_full, summary = report_text_obj)
 }
@@ -140,9 +189,13 @@ report_text.Date <- report_text.factor
 
 # report_statistics -------------------------------------------------------
 
-
 #' @export
-report_statistics.factor <- function(x, table = NULL, levels_percentage = "auto", ...) {
+report_statistics.factor <- function(
+  x,
+  table = NULL,
+  levels_percentage = "auto",
+  ...
+) {
   if (!is.factor(x)) {
     x <- as.factor(x)
   }
@@ -152,27 +205,37 @@ report_statistics.factor <- function(x, table = NULL, levels_percentage = "auto"
 
   text_levels <- paste0(table$Level)
   text_n_Obs <- paste0("n = ", table$n_Obs)
-  text_percentage_Obs <- paste0(insight::format_value(table$percentage_Obs), "%")
+  text_percentage_Obs <- paste0(
+    insight::format_value(table$percentage_Obs),
+    "%"
+  )
 
   text_full <- paste0(
-    text_levels, ", ",
-    text_n_Obs, ", ",
+    text_levels,
+    ", ",
+    text_n_Obs,
+    ", ",
     text_percentage_Obs
   )
 
   if (isTRUE(levels_percentage)) {
     report_text_obj <- paste0(
-      text_levels, ", ",
+      text_levels,
+      ", ",
       text_percentage_Obs
     )
   } else {
     report_text_obj <- paste0(
-      text_levels, ", ",
+      text_levels,
+      ", ",
       text_n_Obs
     )
   }
 
-  as.report_statistics(paste(text_full, collapse = "; "), summary = paste(report_text_obj, collapse = "; "))
+  as.report_statistics(
+    paste(text_full, collapse = "; "),
+    summary = paste(report_text_obj, collapse = "; ")
+  )
 }
 
 #' @export
