@@ -1,14 +1,16 @@
 #' @rdname report.data.frame
 #' @export
-report.numeric <- function(x,
-                           n = FALSE,
-                           centrality = "mean",
-                           dispersion = TRUE,
-                           range = TRUE,
-                           distribution = FALSE,
-                           missing_percentage = "auto",
-                           digits = 2,
-                           ...) {
+report.numeric <- function(
+  x,
+  n = FALSE,
+  centrality = "mean",
+  dispersion = TRUE,
+  range = TRUE,
+  distribution = FALSE,
+  missing_percentage = "auto",
+  digits = 2,
+  ...
+) {
   # Print warning if only two different vars
   if (length(unique(x)) <= 2) {
     if (is.null(names(x))) {
@@ -16,12 +18,18 @@ report.numeric <- function(x,
     } else {
       name <- names(x)
     }
-    warning(insight::format_message(
-      paste0(
-        "Variable `", name, "` contains only ", length(unique(x)),
-        "different values. Consider converting it to a factor."
-      )
-    ), call. = FALSE)
+    warning(
+      insight::format_message(
+        paste0(
+          "Variable `",
+          name,
+          "` contains only ",
+          length(unique(x)),
+          "different values. Consider converting it to a factor."
+        )
+      ),
+      call. = FALSE
+    )
   }
 
   numeric_table <- report_table(
@@ -54,15 +62,17 @@ report.numeric <- function(x,
 # report_table ------------------------------------------------------------
 
 #' @export
-report_table.numeric <- function(x,
-                                 n = FALSE,
-                                 centrality = "mean",
-                                 dispersion = TRUE,
-                                 range = TRUE,
-                                 distribution = FALSE,
-                                 missing_percentage = "auto",
-                                 digits = 2,
-                                 ...) {
+report_table.numeric <- function(
+  x,
+  n = FALSE,
+  centrality = "mean",
+  dispersion = TRUE,
+  range = TRUE,
+  distribution = FALSE,
+  missing_percentage = "auto",
+  digits = 2,
+  ...
+) {
   missing_percentage <- .report_dataframe_percentage(x, missing_percentage)
 
   table_full <- data.frame(
@@ -84,7 +94,9 @@ report_table.numeric <- function(x,
   summary_table <- table_full
 
   # N observations
-  if (isFALSE(n)) summary_table$n_Obs <- NULL
+  if (isFALSE(n)) {
+    summary_table$n_Obs <- NULL
+  }
 
   # Centrality and dispersion
   if (!isFALSE(centrality) && !is.null(centrality)) {
@@ -92,12 +104,21 @@ report_table.numeric <- function(x,
       if (dispersion) {
         summary_table <- datawizard::data_remove(summary_table, c("Mean", "SD"))
       } else {
-        summary_table <- datawizard::data_remove(summary_table, c("Mean", "SD", "MAD"))
+        summary_table <- datawizard::data_remove(
+          summary_table,
+          c("Mean", "SD", "MAD")
+        )
       }
     } else if (dispersion) {
-      summary_table <- datawizard::data_remove(summary_table, c("Median", "MAD"))
+      summary_table <- datawizard::data_remove(
+        summary_table,
+        c("Median", "MAD")
+      )
     } else {
-      summary_table <- datawizard::data_remove(summary_table, c("Median", "MAD", "SD"))
+      summary_table <- datawizard::data_remove(
+        summary_table,
+        c("Median", "MAD", "SD")
+      )
     }
   }
 
@@ -108,18 +129,30 @@ report_table.numeric <- function(x,
 
   # Distribution
   if (!distribution) {
-    summary_table <- datawizard::data_remove(summary_table, c("Skewness", "Kurtosis"))
+    summary_table <- datawizard::data_remove(
+      summary_table,
+      c("Skewness", "Kurtosis")
+    )
   }
 
   # Missing
   if (is.null(missing_percentage)) {
-    summary_table <- datawizard::data_remove(summary_table, c("percentage_Missing", "n_Missing"))
-    table_full <- datawizard::data_remove(table_full, c("percentage_Missing", "n_Missing"))
+    summary_table <- datawizard::data_remove(
+      summary_table,
+      c("percentage_Missing", "n_Missing")
+    )
+    table_full <- datawizard::data_remove(
+      table_full,
+      c("percentage_Missing", "n_Missing")
+    )
   } else if (isTRUE(missing_percentage)) {
     summary_table <- datawizard::data_remove(summary_table, "n_Missing")
     table_full <- datawizard::data_remove(table_full, "n_Missing")
   } else {
-    summary_table <- datawizard::data_remove(summary_table, "percentage_Missing")
+    summary_table <- datawizard::data_remove(
+      summary_table,
+      "percentage_Missing"
+    )
     table_full <- datawizard::data_remove(table_full, "percentage_Missing")
   }
 
@@ -130,16 +163,18 @@ report_table.numeric <- function(x,
 # report_parameters -------------------------------------------------------
 
 #' @export
-report_parameters.numeric <- function(x,
-                                      table = NULL,
-                                      n = FALSE,
-                                      centrality = "mean",
-                                      dispersion = TRUE,
-                                      range = TRUE,
-                                      distribution = FALSE,
-                                      missing_percentage = "auto",
-                                      digits = 2,
-                                      ...) {
+report_parameters.numeric <- function(
+  x,
+  table = NULL,
+  n = FALSE,
+  centrality = "mean",
+  dispersion = TRUE,
+  range = TRUE,
+  distribution = FALSE,
+  missing_percentage = "auto",
+  digits = 2,
+  ...
+) {
   missing_percentage <- .report_dataframe_percentage(x, missing_percentage)
 
   # Get table
@@ -158,11 +193,20 @@ report_parameters.numeric <- function(x,
   }
 
   # Compute text elements ---
-  text_n <- paste0("n = ", insight::format_value(table$n_Obs, protect_integers = TRUE))
+  text_n <- paste0(
+    "n = ",
+    insight::format_value(table$n_Obs, protect_integers = TRUE)
+  )
 
   # Centrality
-  text_mean <- paste0("Mean = ", insight::format_value(table$Mean[1], digits = digits))
-  text_median <- paste0("Median = ", insight::format_value(table$Median[1], digits = digits))
+  text_mean <- paste0(
+    "Mean = ",
+    insight::format_value(table$Mean[1], digits = digits)
+  )
+  text_median <- paste0(
+    "Median = ",
+    insight::format_value(table$Median[1], digits = digits)
+  )
 
   # Dispersion
   text_sd <- insight::format_value(table$SD[1], digits = digits)
@@ -171,13 +215,25 @@ report_parameters.numeric <- function(x,
   # Range
   text_range <- paste0(
     "[",
-    insight::format_value(table$Min[1], protect_integers = TRUE, digits = digits),
-    ", ", insight::format_value(table$Max[1], protect_integers = TRUE), "]"
+    insight::format_value(
+      table$Min[1],
+      protect_integers = TRUE,
+      digits = digits
+    ),
+    ", ",
+    insight::format_value(table$Max[1], protect_integers = TRUE),
+    "]"
   )
 
   # Distribution
-  text_skewness <- paste0("Skewness = ", insight::format_value(table$Skewness[1]))
-  text_kurtosis <- paste0("Kurtosis = ", insight::format_value(table$Kurtosis[1]))
+  text_skewness <- paste0(
+    "Skewness = ",
+    insight::format_value(table$Skewness[1])
+  )
+  text_kurtosis <- paste0(
+    "Kurtosis = ",
+    insight::format_value(table$Kurtosis[1])
+  )
 
   # Missing
   if (is.null(missing_percentage)) {
@@ -185,7 +241,8 @@ report_parameters.numeric <- function(x,
   } else if (isTRUE(missing_percentage)) {
     n_missing <- table$percentage_Missing[1]
     text_missing <- paste0(
-      insight::format_value(table$percentage_Missing[1],
+      insight::format_value(
+        table$percentage_Missing[1],
         protect_integers = TRUE,
         digits = digits
       ),
@@ -212,23 +269,32 @@ report_parameters.numeric <- function(x,
   result_text <- text_full
 
   # N observations
-  if (isFALSE(n)) result_text <- result_text[names(result_text) != "n_Obs"]
+  if (isFALSE(n)) {
+    result_text <- result_text[names(result_text) != "n_Obs"]
+  }
 
   # Centrality and dispersion
   if (!isFALSE(centrality) && !is.null(centrality)) {
     if (centrality == "median") {
-      result_text <- result_text[!names(result_text) %in% c("Mean", "Dispersion_Mean")]
+      result_text <- result_text[
+        !names(result_text) %in% c("Mean", "Dispersion_Mean")
+      ]
       if (!dispersion) {
         result_text <- result_text[names(result_text) != "Dispersion_Median"]
       }
     } else {
-      result_text <- result_text[!names(result_text) %in% c("Median", "Dispersion_Median")]
+      result_text <- result_text[
+        !names(result_text) %in% c("Median", "Dispersion_Median")
+      ]
       if (!dispersion) {
         result_text <- result_text[names(result_text) != "Dispersion_Mean"]
       }
     }
   } else {
-    result_text <- result_text[!names(result_text) %in% c("Mean", "Dispersion_Mean", "Median", "Dispersion_Median")]
+    result_text <- result_text[
+      !names(result_text) %in%
+        c("Mean", "Dispersion_Mean", "Median", "Dispersion_Median")
+    ]
   }
 
   # Range
@@ -238,7 +304,9 @@ report_parameters.numeric <- function(x,
 
   # Distribution
   if (!distribution) {
-    result_text <- result_text[!names(result_text) %in% c("Skewness", "Kurtosis")]
+    result_text <- result_text[
+      !names(result_text) %in% c("Skewness", "Kurtosis")
+    ]
   }
 
   if (is.null(missing_percentage) || n_missing == 0) {
@@ -252,16 +320,18 @@ report_parameters.numeric <- function(x,
 # report_text -------------------------------------------------------------
 
 #' @export
-report_text.numeric <- function(x,
-                                table = NULL,
-                                n = FALSE,
-                                centrality = "mean",
-                                dispersion = TRUE,
-                                range = TRUE,
-                                distribution = FALSE,
-                                missing_percentage = "auto",
-                                digits = 2,
-                                ...) {
+report_text.numeric <- function(
+  x,
+  table = NULL,
+  n = FALSE,
+  centrality = "mean",
+  dispersion = TRUE,
+  range = TRUE,
+  distribution = FALSE,
+  missing_percentage = "auto",
+  digits = 2,
+  ...
+) {
   if (!is.null(list(...)$varname)) {
     name <- list(...)$varname
   } else if (is.null(names(x))) {
@@ -302,18 +372,19 @@ report_text.numeric <- function(x,
 
 # report_statistics -------------------------------------------------------
 
-
 #' @export
-report_statistics.numeric <- function(x,
-                                      table = NULL,
-                                      n = FALSE,
-                                      centrality = "mean",
-                                      dispersion = TRUE,
-                                      range = TRUE,
-                                      distribution = FALSE,
-                                      missing_percentage = "auto",
-                                      digits = 2,
-                                      ...) {
+report_statistics.numeric <- function(
+  x,
+  table = NULL,
+  n = FALSE,
+  centrality = "mean",
+  dispersion = TRUE,
+  range = TRUE,
+  distribution = FALSE,
+  missing_percentage = "auto",
+  digits = 2,
+  ...
+) {
   # Get parameters
   params <- report_parameters(
     x,
