@@ -19,16 +19,44 @@
   interpretation <- do.call(effectsize::interpret, es_args)$Interpretation
   rules <- .text_effectsize(attr(attr(interpretation, "rules"), "rule_name"))
 
-  main <- switch(estimate,
-    Cramers_v_adjusted = paste0("Adjusted Cramer's v = ", insight::format_value(es_table[[estimate]])),
-    Tschuprows_t = paste0("Tschuprow's t = ", insight::format_value(es_table[[estimate]])),
-    Tschuprows_t_adjusted = paste0("Adjusted Tschuprow's t = ", insight::format_value(es_table[[estimate]])),
-    Pearsons_c = paste0("Pearson's c = ", insight::format_value(es_table[[estimate]])),
-    phi_adjusted = paste0("Adjusted Phi = ", insight::format_value(es_table[[estimate]])),
-    Cohens_h = paste0("Cohen's h = ", insight::format_value(es_table[[estimate]])),
-    Odds_ratio = paste0("Odds ratio = ", insight::format_value(es_table[[estimate]])),
-    Ris_kratio = paste0("Risk ratio = ", insight::format_value(es_table[[estimate]])),
-    cohens_h = paste0("Cohen's w = ", insight::format_value(es_table[[estimate]])),
+  main <- switch(
+    estimate,
+    Cramers_v_adjusted = paste0(
+      "Adjusted Cramer's v = ",
+      insight::format_value(es_table[[estimate]])
+    ),
+    Tschuprows_t = paste0(
+      "Tschuprow's t = ",
+      insight::format_value(es_table[[estimate]])
+    ),
+    Tschuprows_t_adjusted = paste0(
+      "Adjusted Tschuprow's t = ",
+      insight::format_value(es_table[[estimate]])
+    ),
+    Pearsons_c = paste0(
+      "Pearson's c = ",
+      insight::format_value(es_table[[estimate]])
+    ),
+    phi_adjusted = paste0(
+      "Adjusted Phi = ",
+      insight::format_value(es_table[[estimate]])
+    ),
+    Cohens_h = paste0(
+      "Cohen's h = ",
+      insight::format_value(es_table[[estimate]])
+    ),
+    Odds_ratio = paste0(
+      "Odds ratio = ",
+      insight::format_value(es_table[[estimate]])
+    ),
+    Ris_kratio = paste0(
+      "Risk ratio = ",
+      insight::format_value(es_table[[estimate]])
+    ),
+    cohens_h = paste0(
+      "Cohen's w = ",
+      insight::format_value(es_table[[estimate]])
+    ),
     paste0(estimate, " = ", insight::format_value(es_table[[estimate]]))
   )
 
@@ -44,11 +72,18 @@
     replacement = paste0(estimate, c("_CI_low", "_CI_high"))
   )
 
-  result_table <- result_table[c(estimate, paste0(estimate, c("_CI_low", "_CI_high")))]
+  result_table <- result_table[c(
+    estimate,
+    paste0(estimate, c("_CI_low", "_CI_high"))
+  )]
 
   list(
-    table = result_table, statistics = statistics, interpretation = interpretation,
-    rules = rules, ci = ci, main = main
+    table = result_table,
+    statistics = statistics,
+    interpretation = interpretation,
+    rules = rules,
+    ci = ci,
+    main = main
   )
 }
 
@@ -60,7 +95,8 @@
   final_text <- paste0(
     trimws(x$method),
     " testing the association between the variables of the ",
-    x$data.name, " dataset "
+    x$data.name,
+    " dataset "
   )
 
   final_text
