@@ -60,7 +60,6 @@ report_parameters <- function(x, ...) {
 
 # METHODS -----------------------------------------------------------------
 
-
 #' @rdname as.report
 #' @export
 as.report_parameters <- function(x, summary = NULL, prefix = "  - ", ...) {
@@ -79,13 +78,17 @@ as.report_parameters <- function(x, summary = NULL, prefix = "  - ", ...) {
 #' @export
 as.character.report_parameters <- function(x, prefix = NULL, ...) {
   # Find prefix
-  if (is.null(prefix)) prefix <- attributes(x)$prefix
-  if (is.null(prefix)) prefix <- ""
+  if (is.null(prefix)) {
+    prefix <- attributes(x)$prefix
+  }
+  if (is.null(prefix)) {
+    prefix <- ""
+  }
 
   # Concatenate
-  text <- paste0(prefix, x)
-  text <- paste(text, collapse = "\n")
-  text
+  text_output <- paste0(prefix, x)
+  text_output <- paste(text_output, collapse = "\n")
+  text_output
 }
 
 #' @export
@@ -111,7 +114,10 @@ print.report_parameters <- function(x, ...) {
   for (i in seq_along(names)) {
     if (grepl(":", names[i], fixed = TRUE)) {
       interaction_terms <- unlist(strsplit(names[i], ":", fixed = TRUE))
-      names[i] <- paste0("The interaction between ", datawizard::text_concatenate(interaction_terms))
+      names[i] <- paste0(
+        "The interaction between ",
+        datawizard::text_concatenate(interaction_terms)
+      )
     } else {
       names[i] <- paste0("The main effect of ", names[i])
     }
@@ -126,7 +132,12 @@ print.report_parameters <- function(x, ...) {
     if (grepl(" * ", names[i], fixed = TRUE)) {
       parts <- unlist(strsplit(names[i], " * ", fixed = TRUE))
       basis <- paste(utils::head(parts, -1), collapse = " * ")
-      names[i] <- paste0("The interaction effect of ", utils::tail(parts, 1), " on ", basis)
+      names[i] <- paste0(
+        "The interaction effect of ",
+        utils::tail(parts, 1),
+        " on ",
+        basis
+      )
 
       # Intercept
     } else if (names[i] == "(Intercept)") {
@@ -144,25 +155,88 @@ print.report_parameters <- function(x, ...) {
 .parameters_starting_text <- function(x, params) {
   if ("pretty_names" %in% attributes(params)) {
     pretty_name <- attributes(params)$pretty_names[params$Parameter]
+  } else if (
+    inherits(x, "glmmTMB") &&
+      "Component" %in% colnames(params) &&
+      length(unique(params$Component[!is.na(params$Component)])) > 1
+  ) {
+    # For glmmTMB models with multiple components, need to handle component-specific naming
+    # Create component-aware parameter names for glmmTMB models
+    formatted_params <- parameters::format_parameters(x)
+    # Map parameter names to include component information
+    pretty_name <- character(nrow(params))
+    for (i in seq_len(nrow(params))) {
+      param_name <- params$Parameter[i]
+      component <- params$Component[i]
+
+      if (
+        !is.na(param_name) &&
+          !is.na(component) &&
+          param_name %in% names(formatted_params)
+      ) {
+        if (component == "dispersion") {
+          # For dispersion component, modify the name to indicate it affects variability
+          if (param_name == "(Intercept)") {
+            pretty_name[i] <- "(Intercept) (dispersion)"
+          } else {
+            pretty_name[i] <- paste0(
+              formatted_params[param_name],
+              " (on dispersion)"
+            )
+          }
+        } else {
+          # For conditional component, use standard name
+          pretty_name[i] <- formatted_params[param_name]
+        }
+      } else {
+        pretty_name[i] <- param_name
+      }
+    }
+    names(pretty_name) <- params$Parameter
   } else {
-    pretty_name <- parameters::format_parameters(x)
+    # Try to get formatted parameter names from the model
+    # If this fails (e.g., with mock objects), fall back to using parameter names from table
+    pretty_name <- tryCatch(
+      {
+        parameters::format_parameters(x)
+      },
+      warning = function(w) {
+        # If we can't get parameters from the model, use the parameter names from the table
+        param_names <- params$Parameter
+        names(param_names) <- param_names
+        param_names
+      },
+      error = function(e) {
+        # If we can't get parameters from the model, use the parameter names from the table
+        param_names <- params$Parameter
+        names(param_names) <- param_names
+        param_names
+      }
+    )
   }
 
-  text <- vapply(pretty_name,
+  text_output <- vapply(
+    pretty_name,
     .format_parameters_regression,
-    USE.NAMES = TRUE, "character"
+    USE.NAMES = TRUE,
+    "character"
   )
 
-  text
+  text_output
 }
 
 
 #' @keywords internal
-.parameters_diagnostic_bayesian <- function(diagnostic, only_when_insufficient = FALSE, ...) {
+.parameters_diagnostic_bayesian <- function(
+  diagnostic,
+  only_when_insufficient = FALSE,
+  ...
+) {
   # Convergence
   if ("Rhat" %in% names(diagnostic)) {
     convergence <- effectsize::interpret_rhat(diagnostic$Rhat, ...)
-    text <- ifelse(convergence == "converged",
+    text_output <- ifelse(
+      convergence == "converged",
       paste0(
         "The estimation successfully converged (Rhat = ",
         insight::format_value(diagnostic$Rhat, digits = 3),
@@ -177,36 +251,52 @@ print.report_parameters <- function(x, ...) {
 
     if ("ESS" %in% names(diagnostic)) {
       stability <- effectsize::interpret_ess(diagnostic$ESS, ...)
-      text <- lapply(seq_len(length(stability)), function(x) {
-        y <- switch(EXPR = paste(stability[x] == "sufficient", convergence[x] == "converged"),
+      text_output <- lapply(seq_along(stability), function(x) {
+        y <- switch(
+          EXPR = paste(
+            stability[x] == "sufficient",
+            convergence[x] == "converged"
+          ),
           "TRUE TRUE" = paste0(
-            text, " and the indices are reliable (ESS = ",
-            insight::format_value(diagnostic$ESS, digits = 0), ")"
+            text_output,
+            " and the indices are reliable (ESS = ",
+            insight::format_value(diagnostic$ESS, digits = 0),
+            ")"
           ),
           "TRUE FALSE" = paste0(
-            text, " even though the indices appear as reliable (ESS = ",
-            insight::format_value(diagnostic$ESS, digits = 0), ")"
+            text_output,
+            " even though the indices appear as reliable (ESS = ",
+            insight::format_value(diagnostic$ESS, digits = 0),
+            ")"
           ),
           "FALSE TRUE" = paste0(
-            text, " but the indices are unreliable (ESS = ",
-            insight::format_value(diagnostic$ESS, digits = 0), ")"
+            text_output,
+            " but the indices are unreliable (ESS = ",
+            insight::format_value(diagnostic$ESS, digits = 0),
+            ")"
           ),
           "FALSE FALSE" = paste0(
-            text, " and the indices are unreliable (ESS = ",
-            insight::format_value(diagnostic$ESS, digits = 0), ")"
+            text_output,
+            " and the indices are unreliable (ESS = ",
+            insight::format_value(diagnostic$ESS, digits = 0),
+            ")"
           )
         )
         y[[x]]
       })
-      text <- unlist(text)
+      text_output <- unlist(text_output)
     }
   } else {
-    text <- ""
+    text_output <- ""
   }
 
-  if (!only_when_insufficient) {
-    text
+  if (only_when_insufficient) {
+    ifelse(
+      convergence != "converged" | stability != "sufficient",
+      text_output,
+      ""
+    )
   } else {
-    ifelse(convergence != "converged" | stability != "sufficient", text, "")
+    text_output
   }
 }
